@@ -10,10 +10,12 @@ Command line interface for Firebat.
 import os
 import signal
 import logging
-import json
 import pprint
 pp = pprint.PrettyPrinter(indent=4)
 
+import simplejson as json
+from simplejson.decoder import JSONDecodeError
+
 
 def get_logger(is_debug=False):
     '''Return logger obj with console hendler.
@@ -50,7 +52,7 @@ def get_running_fires(pids_path='/tmp/fire/', logger=None):
         return
 
     for pid_file in os.listdir(pids_path):
-        with open(pids_path + pid_file, "r") as pid_fh:
+        with open(pids_path + pid_file, 'r') as pid_fh:
             pid = int(pid_fh.read())
         if os.path.exists('/proc/%s' % pid):
             yield pid
@@ -72,12 +74,12 @@ def get_fire_info(pid, dumps_pth='/tmp', logger=None):
     state = None
     try:
         path = '%s/%s.fire' % (dumps_pth, pid)
-        with open(path) as state_fh:
+        with open(path, 'r') as state_fh:
             state_json = state_fh.read()
         state = json.loads(state_json)
     except IOError as e:
         logger.error('Can\'t read state dump from: %s' % path)
-    except ValueError, e:
+    except JSONDecodeError, e:
         logger.error('Can\'t parse fire status data geted from: %s\n%s' %\
                      (path, e))
     return state
